@@ -8,7 +8,7 @@ import (
 	"strings"
 
 	sm "cloud.google.com/go/secretmanager/apiv1"
-	smpb "google.golang.org/genproto/googleapis/cloud/secretmanager/v1"
+	smpb "cloud.google.com/go/secretmanager/apiv1/secretmanagerpb"
 	"gopkg.in/yaml.v3"
 
 	"github.com/helmfile/vals/pkg/api"
