@@ -30,8 +30,10 @@ import (
 	"github.com/helmfile/vals/pkg/providers/gcpsecrets"
 	"github.com/helmfile/vals/pkg/providers/gcs"
 	"github.com/helmfile/vals/pkg/providers/gitlab"
+	"github.com/helmfile/vals/pkg/providers/gkms"
 	"github.com/helmfile/vals/pkg/providers/googlesheets"
 	"github.com/helmfile/vals/pkg/providers/onepasswordconnect"
+	"github.com/helmfile/vals/pkg/providers/pulumi"
 	"github.com/helmfile/vals/pkg/providers/s3"
 	"github.com/helmfile/vals/pkg/providers/sops"
 	"github.com/helmfile/vals/pkg/providers/ssm"
@@ -85,6 +87,8 @@ const (
 	ProviderEnvSubst           = "envsubst"
 	ProviderOnePasswordConnect = "onepasswordconnect"
 	ProviderDoppler            = "doppler"
+	ProviderPulumiStateAPI     = "pulumistateapi"
+	ProviderGKMS               = "gkms"
 )
 
 var (
@@ -238,6 +242,12 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 		case ProviderDoppler:
 			p := doppler.New(r.logger, conf)
 			return p, nil
+		case ProviderPulumiStateAPI:
+			p := pulumi.New(r.logger, conf, "pulumistateapi")
+			return p, nil
+		case ProviderGKMS:
+			p := gkms.New(r.logger, conf)
+			return p, nil
 		}
 		return nil, fmt.Errorf("no provider registered for scheme %q", scheme)
 	}
@@ -439,6 +449,7 @@ var KnownValuesTypes = []string{
 	ProviderFile,
 	ProviderEcho,
 	ProviderEnvSubst,
+	ProviderPulumiStateAPI,
 }
 
 type ctx struct {
